==> KleckFiles(5.98.00).zip: KleckFiles/wiki/page/project/codePage.js <==
var wikiMetaData = {created:'230808', modified:'230815'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Special Codes</h1>",
"<p>Page source files contain a mixture of HTML and wiki mark-up (special codes to extend the language). Extensions are achieved using special class=\"names\" and id=\"names\" etc. When the wiki page code sees these special codes the required feature is inserted.</p>",
"",
"<h2 class=\"pageTOC\">Page Jump table</h2>",
"<p>Generate a page table of contents by adding an empty DIV anywhere in the page (as below with class=\"pageTOC\" id=\"pageTOC\"). Then add class=\"pageTOC\" to each heading or control you want bookmarked. Ctrl+click a jump table link to create a jump URL in a new page.</p>",
"",
"<textarea readonly>",
"  <div class=\"pageTOC\" id=\"pageTOC\"></div>",
"",
"  <h2 class=\"pageTOC\">KleckFile video thumbnails</h2>",
" ...",
"</textarea>",
"",
"<div class=\"pageTOC\" id=\"pageTOC\" style=\"margin: 12px 0px;\"></div>",
"",
"",
	

"<h2 class=\"pageTOC\">Tabbed Media</h2>",
"<p>_w_media class lets you show images and JKClips docked in a single DIV controlled by tabs.</p>",
"",
'<textarea class="_w_liveedit" data-live-target="_w_media_liveedit" data-live-class="_w_media">',
	'<div class="_w_media" data-targetid="jaguar2">',
	'/2020/01/31/20200131124813-b146cc14.jpg|width:850px;',
	'||@pic:pic2|/2020/01/31/20200131125018-eef4689b.jpg|width:850px;',
	'||@pic:pic3|/2020/01/31/20200131124836-3b224444.jpg|width:850px;',
	'||@space:|width:16px;',
	'||@clips|Jaguar - British Villains',
	'||@space:|width:16px;',
	'||@youtube:YTube|RcNb--Zv4bk	',
	'</div>',
	'<div id="jaguar2">media docks in here..</div>',
'</textarea>',
"",
"<div id='_w_media_liveedit'></div>",
"",
"<br>",

	
"<h2 class=\"pageTOC\">Images</h2>",
"<p>Use &lt;div class=\"_w_images\"&gt;img1||img2||img3&lt;/div&gt; to show images.",
"Where img1 = a filepath|optional_style; eg: /2020/...png|width:500px;",
"</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_images_liveEdit\" data-live-class=\"_w_images\">",
"<div class='_w_images'>",
	'/2020/01/31/20200131124813-b146cc14.jpg|width:850px',
	'||/2020/01/31/20200131125018-eef4689b.jpg|width:850px',
	'||/2020/01/31/20200131124836-3b224444.jpg|width:850px',
"</div>",
"</textarea>",
"",	
"<div id='_w_images_liveEdit'></div>",
"",
"<br>",	

	
	
"<h2 class=\"pageTOC\">Embed KleckFile Video</h2>",
"<p>Embed a KleckFile video. All you need is a DIV with class=\"_w_EmbedKFVideo\" and id=\"video_230801\"  where 230801 indicates the KleckFiles ID.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_EmbedKFVideo_liveedit\" data-live-class=\"_w_EmbedKFVideo\">",
"<div class=\"_w_EmbedKFVideo\" id=\"video_230801\"></div>",
"</textarea>",
"",
"<div id='_w_EmbedKFVideo_liveedit'></div>",
"",
"<p>This example contains a data-vtime= attibute to set the start time in seconds.</p>",
	
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_EmbedKFVideo_liveedit2\" data-live-class=\"_w_EmbedKFVideo\">",
"<div class=\"_w_EmbedKFVideo\" id=\"video_221231\" data-vtime=\"666.02\"></div>",
"</textarea>",
"",
"<div id='_w_EmbedKFVideo_liveedit2'></div>",
"",
"",
	
	
	
"<h2 class=\"pageTOC\">Video buttons / Link - Switch video</h2>",
"<p>Create target video container with id= as above.</p>",
"<p>Use class=\"_w_videoButtons\" to create video jump buttons.<br>",
"The text inside = 'targetID|vidID,textLink,start|vidID,textLink,start|vidID,textLink,start'",
"<br>Use class=\"_w_videoLink\" to create a single video link instead of buttons.",
"</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoButtons_liveedit3\" data-live-class=\"_w_videoButtons\">",
"<!-- video buttons will change this DIV -- remove class= to close initially -->",
"<div class=\"_w_EmbedKFVideo\" id=\"video_230806-01\"></div>",
"",
"<div class=\"_w_videoButtons\">video_230806-01|230806-01,The Serpents World|230806-02,HD(1080p)|230806-03,More Commentary,1200.47</div>",
"",
"<p>Single link form: <span class=\"_w_videoLink\">video_230806-01|230806-03,More Commentary,1200.47</span></p>",
"</textarea>",	
"",
"<div id='_w_videoButtons_liveedit3'></div>",
"",	
"",
"",
"",
"<h2 class=\"pageTOC\">KleckFile video thumbnails</h2>",
"<p>Generate a list of 1 or more KF video thumbnails</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoThumbs_liveedit\" data-live-class=\"_w_videoThumbs\">",
"<div class=\"_w_videoThumbs\">190316, 190320</div>",
"</textarea>",
"",
"<div id='_w_videoThumbs_liveedit'></div>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoThumbs_liveedit2\" data-live-class=\"_w_videoThumbs\">",
"<div class=\"_w_videoThumbs\">221231</div>",
"",
"<p>Note: Special keyword \"shorts\" - shows all video shorts thumbnails - from KF_LIST.js _shortVidsList=[...]</p>",
"</textarea>",
"",
"<div id='_w_videoThumbs_liveedit2'></div>",
"",
"",
	
"<h2 class=\"pageTOC\">List all KF favorites</h2>",
"<p>Thumb list of all Kleck favorites in /html/KF_LIST.js</p>",
"<textarea readonly><div class=\"_w_KF_LIST_Favs\"></div>",
"</textarea>",
"",
"<p>To see the result go to <a href=\"wiki.html?kleckFavs\" target=\"_blank\">KleckFiles Favorites demo</a></p>",
"",
"",
"<h2 class=\"pageTOC\">Link to pageId</h2>",
"<p>Internal jump to pageId (with optional link text). If you want to jump to another book or want the URL in the browser address bar then use a standard HTML link.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_pageLink_liveedit\" data-live-class=\"_w_pageLink\">",
"Link to cmdline page (no link text) <span class=\"_w_pageLink\">cmdline</span><br>",
"Link to cmdline (link text provided) <span class=\"_w_pageLink\">cmdline | cmdline with link text</span><br><br>",
"A normal intra-book HTML anchor link <a href=\"wiki.html?@pl&KleckFavs\" target=\"_blank\">wiki.html?@pl&KleckFavs</a>",
"</textarea>",
"",
"<div id='_w_pageLink_liveedit'>",
"</div>",
"",
"",
"",
"",
"<h2 class=\"pageTOC\">Expando Section</h2>",
"<p>To make say a H1 expando section create the title and add class=\"_w_expando\". Give it a page unique id=\"someid\". In you expanding block set the class=\"someid\" (same id). </p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_expando_liveedit\" data-live-class=\"_w_expando\">",
"<h3 class=\"_w_expando\" id=\"myUniqueId_1\">This is my header text</h3>",
"<div class=\"myUniqueId_1\" style=\"background-color: yellow; margin:12px;\">",
"expando block for \"myUniqueId_1\"",
"<br>text line 1",
"<br>text line 2",
"<br>text line 3",
"</div>",
"</textarea>",
	
"",
"<div id='_w_expando_liveedit'>",
"</div>",
"",
"<p>Add a close parameter to start the section closed.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_expando_liveedit2\" data-live-class=\"_w_expando\">",
"<h3 class=\"_w_expando\" id=\"myUniqueId_2\">This is my header text | close </h3>",
"<div class=\"myUniqueId_2\" style=\"background-color: pink; margin:12px;\">",
"expando block for \"myUniqueId_2\"",
"<br>text line 1",
"<br>text line 2",
"<br>text line 3",
"</div>",
"</textarea>",
"",
"<div id='_w_expando_liveedit2'>",
"</div>",
"",
"",
"",
"<h2 class=\"pageTOC\">Render Bible Verse</h2>",
"<p>Any bible text container with class=\"_w_bibleVerse\" will have codes expanded into links.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_bibleVerse_liveedit\" data-live-class=\"_w_bibleVerse\">",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Mat 3:8|Bring forthG4160 thereforeG3767 fruitsG2590 meetG514 for repentance:G3341",
"</div>",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Pro 3:5  Trust in the LORD with all thine heart; and lean not unto thine own understanding.||Pro 3:6  In all thy ways acknowledge him, and he shall direct thy paths.",
"</div>",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Pro 3:5  Trust in the LORD with all thine heart; and lean not unto thine own understanding.<br>||/Pro 3:6  In all thy ways acknowledge him, and he shall direct thy paths.",
"</div>",
	
"<p><b>Strongs ON/OFF</b> -- presence of class='_w_hideStrongs' or class='_w_showStrongs' will load a page in a known state",
"</p>",
"<p class='_w_glossary' >((@strongs|/Genesis 1:1))</p>",
"<p class='_w_glossary' >((@strongs|@/Genesis 1:2))</p>",
"<p class='_w_glossary' >((@strongs|Show Strongs/Genesis 2))</p>",
"<p class='_w_glossary' >((@strongs))</p>",
"</textarea>",
"",
"<div id='_w_bibleVerse_liveedit'>",
"</div>",
"",
"<p class='_w_showStrongs _w_glossary'>((@strongs))</p>",
"<p>This will show Strongs toggle button and enable strongs on this page by default.<br> &lt;p class='_w_showStrongs _w_glossary' &gt;((@strongs@))&lt;/p&gt;</p>",
"",
"",
	
"<h2 class=\"pageTOC\">Strongs, Bible &amp; Glossary Links</h2>",
"<p>Text wrapped in double brackets as ((text)) in a container with class=\"_w_glossary\" will create various links.</p>",
"<div id='_w_glossary_liveEdit'></div>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_glossary_liveEdit\" data-live-class=\"_w_glossary\">",
"<div class=\"_w_glossary\">",
"<ul>",
"<li><b>Strongs Numbers</b> : 'Gnnn' or 'Hnnn' (where nnn is a number - no spaces allowed).",
"<br>Example: Elohim((H430)) + Greek stones((G211)), ((H430|*)) or ((G211|*)) : param 2 (any text) forces normal text size.",
"</li>",
"<li><b>Bible links</b> : book+spc+chapter:verse - links to a KF bible page (space required). ",
"<br>Example : Normal ((John 3)), ((John 3:16)), with alt text ((Joh 3:16|Book of John 3:16)), with style ((John 3:16|Book of John 3:16|color:red;font-weight:bold)).",
"</li>",
"<li><b>Glossary Terms</b> : term|text : ((green|Green love frequency)) and ((baby|baby with blue link|color:royalblue;)).",
"<br>term of '=' will show all gloss terms : ((=|List All Glossary items)).",
"</li>",
"<li><b>Video links</b> : param 1 is target id must start with 'video_' followed by kfid - 'video_kfid_anytext' or 'video_kfid|start-time' or 'video_kfid|start-time/link-text'  or 'video_kfid|start-time/link-text|style' ",
"<br>Example: ((video_230807-02_more|100)) and ((video_230807-02_more|2:33)) and ((video_230807-02_more|7:33)).",
" With text and start-time = 0 ((video_230807-02_more|0/vLinktext|color:red))",
"</li>",
"<li><b>KleckFile ID</b> : 'kfid' or 'kfid|link-text|class' or 'kfid|link-text|style' ",
"<br>Example: ((230807-02)) and ((230819|Show link 230819)) ",
"</li>",
"</ul>",
"<div id='video_230807-02_more'></div>",
"</textarea>",
"",
	
	
"",
"",	
	
"<h2 class=\"pageTOC\">More</h2>",
'<p>Use &lt;div class="_w_cc"&gt;&lt;/div&gt; to list all transcription (Closed Caption) files.</p>',
	
'<p>Use &lt;div class="_w_BlogTalk"&gt;&lt;/div&gt; to list all BlogTalkRadio shows. Use commandline param "devMode" to enter edit mode.</p>',
	

];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/project/codePage.js <==
var wikiMetaData = {created:'230808', modified:'230815'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Special Codes</h1>",
"<p>Page source files contain a mixture of HTML and wiki mark-up (special codes to extend the language). Extensions are achieved using special class=\"names\" and id=\"names\" etc. When the wiki page code sees these special codes the required feature is inserted.</p>",
"",
"<h2 class=\"pageTOC\">Page Jump table</h2>",
"<p>Generate a page table of contents by adding an empty DIV anywhere in the page (as below with class=\"pageTOC\" id=\"pageTOC\"). Then add class=\"pageTOC\" to each heading or control you want bookmarked. Ctrl+click a jump table link to create a jump URL in a new page.</p>",
"",
"<textarea readonly>",
"  <div class=\"pageTOC\" id=\"pageTOC\"></div>",
"",
"  <h2 class=\"pageTOC\">KleckFile video thumbnails</h2>",
" ...",
"</textarea>",
"",
"<div class=\"pageTOC\" id=\"pageTOC\" style=\"margin: 12px 0px;\"></div>",
"",
"",
	

"<h2 class=\"pageTOC\">Tabbed Media</h2>",
"<p>_w_media class lets you show images and JKClips docked in a single DIV controlled by tabs. @clips|154 or @clips|anything_154 will now show clip with id 154 of clips n..1 (reverse index).</p>",
"",
'<textarea class="_w_liveedit" data-live-target="_w_media_liveedit" data-live-class="_w_media">',
	'<div class="_w_media" data-targetid="jaguar2">',
	'/2020/01/31/20200131124813-b146cc14.jpg|width:850px;',
	'||@pic:pic2|/2020/01/31/20200131125018-eef4689b.jpg|width:850px;',
	'||@pic:pic3|/2020/01/31/20200131124836-3b224444.jpg|width:850px;',
	'||@space:|width:16px;',
	'||@clips|Jaguar - British Villains',
	'||@space:|width:16px;',
	'||@youtube:YTube|RcNb--Zv4bk	',
	'||@space:|width:16px;',
	'||@clips:Clip 154|clip_154',
	'</div>',
	'<div id="jaguar2">media docks in here..</div>',
'</textarea>',
"",
"<div id='_w_media_liveedit'></div>",
"",
"<br>",

	
"<h2 class=\"pageTOC\">Images</h2>",
"<p>Use &lt;div class=\"_w_images\"&gt;img1||img2||img3&lt;/div&gt; to show images.",
"Where img1 = a filepath|optional_style; eg: /2020/...png|width:500px;",
"</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_images_liveEdit\" data-live-class=\"_w_images\">",
"<div class='_w_images'>",
	'/2020/01/31/20200131124813-b146cc14.jpg|width:850px',
	'||/2020/01/31/20200131125018-eef4689b.jpg|width:850px',
	'||/2020/01/31/20200131124836-3b224444.jpg|width:850px',
"</div>",
"</textarea>",
"",	
"<div id='_w_images_liveEdit'></div>",
"",
"<br>",	

	
	
"<h2 class=\"pageTOC\">Embed KleckFile Video</h2>",
"<p>Embed a KleckFile video. All you need is a DIV with class=\"_w_EmbedKFVideo\" and id=\"video_230801\"  where 230801 indicates the KleckFiles ID.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_EmbedKFVideo_liveedit\" data-live-class=\"_w_EmbedKFVideo\">",
"<div class=\"_w_EmbedKFVideo\" id=\"video_230801\"></div>",
"</textarea>",
"",
"<div id='_w_EmbedKFVideo_liveedit'></div>",
"",
"<p>This example contains a data-vtime= attibute to set the start time in seconds.</p>",
	
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_EmbedKFVideo_liveedit2\" data-live-class=\"_w_EmbedKFVideo\">",
"<div class=\"_w_EmbedKFVideo\" id=\"video_221231\" data-vtime=\"666.02\"></div>",
"</textarea>",
"",
"<div id='_w_EmbedKFVideo_liveedit2'></div>",
"",
"",
	
	
	
"<h2 class=\"pageTOC\">Video buttons / Link - Switch video</h2>",
"<p>Create target video container with id= as above.</p>",
"<p>Use class=\"_w_videoButtons\" to create video jump buttons.<br>",
"The text inside = 'targetID|vidID,textLink,start|vidID,textLink,start|vidID,textLink,start'",
"<br>Use class=\"_w_videoLink\" to create a single video link instead of buttons.",
"</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoButtons_liveedit3\" data-live-class=\"_w_videoButtons\">",
"<!-- video buttons will change this DIV -- remove class= to close initially -->",
"<div class=\"_w_EmbedKFVideo\" id=\"video_230806-01\"></div>",
"",
"<div class=\"_w_videoButtons\">video_230806-01|230806-01,The Serpents World|230806-02,HD(1080p)|230806-03,More Commentary,1200.47</div>",
"",
"<p>Single link form: <span class=\"_w_videoLink\">video_230806-01|230806-03,More Commentary,1200.47</span></p>",
"</textarea>",	
"",
"<div id='_w_videoButtons_liveedit3'></div>",
"",	
"",
"",
"",
"<h2 class=\"pageTOC\">KleckFile video thumbnails</h2>",
"<p>Generate a list of 1 or more KF video thumbnails</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoThumbs_liveedit\" data-live-class=\"_w_videoThumbs\">",
"<div class=\"_w_videoThumbs\">190316, 190320</div>",
"</textarea>",
"",
"<div id='_w_videoThumbs_liveedit'></div>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_videoThumbs_liveedit2\" data-live-class=\"_w_videoThumbs\">",
"<div class=\"_w_videoThumbs\">221231</div>",
"",
"<p>Note: Special keyword \"shorts\" - shows all video shorts thumbnails - from KF_LIST.js _shortVidsList=[...]</p>",
"</textarea>",
"",
"<div id='_w_videoThumbs_liveedit2'></div>",
"",
"",
	
"<h2 class=\"pageTOC\">List all KF favorites</h2>",
"<p>Thumb list of all Kleck favorites in /html/KF_LIST.js</p>",
"<textarea readonly><div class=\"_w_KF_LIST_Favs\"></div>",
"</textarea>",
"",
"<p>To see the result go to <a href=\"wiki.html?kleckFavs\" target=\"_blank\">KleckFiles Favorites demo</a></p>",
"",
"",
"<h2 class=\"pageTOC\">Link to pageId</h2>",
"<p>Internal jump to pageId (with optional link text). If you want to jump to another book or want the URL in the browser address bar then use a standard HTML link.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_pageLink_liveedit\" data-live-class=\"_w_pageLink\">",
"Link to cmdline page (no link text) <span class=\"_w_pageLink\">cmdline</span><br>",
"Link to cmdline (link text provided) <span class=\"_w_pageLink\">cmdline | cmdline with link text</span><br><br>",
"A normal intra-book HTML anchor link <a href=\"wiki.html?@pl&KleckFavs\" target=\"_blank\">wiki.html?@pl&KleckFavs</a>",
"</textarea>",
"",
"<div id='_w_pageLink_liveedit'>",
"</div>",
"",
"",
"",
"",
"<h2 class=\"pageTOC\">Expando Section</h2>",
"<p>To make say a H1 expando section create the title and add class=\"_w_expando\". Give it a page unique id=\"someid\". In you expanding block set the class=\"someid\" (same id). </p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_expando_liveedit\" data-live-class=\"_w_expando\">",
"<h3 class=\"_w_expando\" id=\"myUniqueId_1\">This is my header text</h3>",
"<div class=\"myUniqueId_1\" style=\"background-color: yellow; margin:12px;\">",
"expando block for \"myUniqueId_1\"",
"<br>text line 1",
"<br>text line 2",
"<br>text line 3",
"</div>",
"</textarea>",
	
"",
"<div id='_w_expando_liveedit'>",
"</div>",
"",
"<p>Add a close parameter to start the section closed.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_expando_liveedit2\" data-live-class=\"_w_expando\">",
"<h3 class=\"_w_expando\" id=\"myUniqueId_2\">This is my header text | close </h3>",
"<div class=\"myUniqueId_2\" style=\"background-color: pink; margin:12px;\">",
"expando block for \"myUniqueId_2\"",
"<br>text line 1",
"<br>text line 2",
"<br>text line 3",
"</div>",
"</textarea>",
"",
"<div id='_w_expando_liveedit2'>",
"</div>",
"",
"",
"",
"<h2 class=\"pageTOC\">Render Bible Verse</h2>",
"<p>Any bible text container with class=\"_w_bibleVerse\" will have codes expanded into links.</p>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_bibleVerse_liveedit\" data-live-class=\"_w_bibleVerse\">",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Mat 3:8|Bring forthG4160 thereforeG3767 fruitsG2590 meetG514 for repentance:G3341",
"</div>",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Pro 3:5  Trust in the LORD with all thine heart; and lean not unto thine own understanding.||Pro 3:6  In all thy ways acknowledge him, and he shall direct thy paths.",
"</div>",
"<div class='_w_bibleVerse' style='font-size:110%'>",
"Pro 3:5  Trust in the LORD with all thine heart; and lean not unto thine own understanding.<br>||/Pro 3:6  In all thy ways acknowledge him, and he shall direct thy paths.",
"</div>",
	
"<p><b>Strongs ON/OFF</b> -- presence of class='_w_hideStrongs' or class='_w_showStrongs' will load a page in a known state",
"</p>",
"<p class='_w_glossary' >((@strongs|/Genesis 1:1))</p>",
"<p class='_w_glossary' >((@strongs|@/Genesis 1:2))</p>",
"<p class='_w_glossary' >((@strongs|Show Strongs/Genesis 2))</p>",
"<p class='_w_glossary' >((@strongs))</p>",
"</textarea>",
"",
"<div id='_w_bibleVerse_liveedit'>",
"</div>",
"",
"<p class='_w_showStrongs _w_glossary'>((@strongs))</p>",
"<p>This will show Strongs toggle button and enable strongs on this page by default.<br> &lt;p class='_w_showStrongs _w_glossary' &gt;((@strongs@))&lt;/p&gt;</p>",
"",
"",
	
"<h2 class=\"pageTOC\">Strongs, Bible &amp; Glossary Links</h2>",
"<p>Text wrapped in double brackets as ((text)) in a container with class=\"_w_glossary\" will create various links.</p>",
"<div id='_w_glossary_liveEdit'></div>",
"",
"<textarea class=\"_w_liveedit\" data-live-target=\"_w_glossary_liveEdit\" data-live-class=\"_w_glossary\">",
"<div class=\"_w_glossary\">",
"<ul>",
"<li><b>Strongs Numbers</b> : 'Gnnn' or 'Hnnn' (where nnn is a number - no spaces allowed).",
"<br>Example: Elohim((H430)) + Greek stones((G211)), ((H430|*)) or ((G211|*)) : param 2 (any text) forces normal text size.",
"</li>",
"<li><b>Bible links</b> : book+spc+chapter:verse - links to a KF bible page (space required). ",
"<br>Example : Normal ((John 3)), ((John 3:16)), with alt text ((Joh 3:16|Book of John 3:16)), with style ((John 3:16|Book of John 3:16|color:red;font-weight:bold)).",
"</li>",
"<li><b>Glossary Terms</b> : term|text : ((green|Green love frequency)) and ((baby|baby with blue link|color:royalblue;)).",
"<br>term of '=' will show all gloss terms : ((=|List All Glossary items)).",
"</li>",
"<li><b>Video links</b> : param 1 is target id must start with 'video_' followed by kfid - 'video_kfid_anytext' or 'video_kfid|start-time' or 'video_kfid|start-time/link-text'  or 'video_kfid|start-time/link-text|style' ",
"<br>Example: ((video_230807-02_more|100)) and ((video_230807-02_more|2:33)) and ((video_230807-02_more|7:33)).",
" With text and start-time = 0 ((video_230807-02_more|0/vLinktext|color:red))",
"</li>",
"<li><b>KleckFile ID</b> : 'kfid' or 'kfid|link-text|class' or 'kfid|link-text|style' ",
"<br>Example: ((230807-02)) and ((230819|Show link 230819)) ",
"</li>",
"</ul>",
"<div id='video_230807-02_more'></div>",
"</textarea>",
"",
	
	
"",
"",	
	
"<h2 class=\"pageTOC\">More</h2>",
'<p>Use &lt;div class="_w_cc"&gt;&lt;/div&gt; to list all transcription (Closed Caption) files.</p>',
	
'<p>Use &lt;div class="_w_BlogTalk"&gt;&lt;/div&gt; to list all BlogTalkRadio shows. Use commandline param "devMode" to enter edit mode.</p>',
	

];
